You are viewing a plain text version of this content. The canonical link for it is here.
Posted to java-dev@axis.apache.org by di...@apache.org on 2008/03/03 23:19:32 UTC

svn commit: r633302 - in /webservices/axis2/trunk/java/modules: adb-codegen/src/org/apache/axis2/schema/ adb/src/org/apache/axis2/databinding/types/soapencoding/ codegen/src/org/apache/axis2/wsdl/codegen/schema/ codegen/src/org/apache/axis2/wsdl/codege...

Author: dims
Date: Mon Mar  3 14:19:27 2008
New Revision: 633302

URL: http://svn.apache.org/viewvc?rev=633302&view=rev
Log:
- s/scheam/schema/g
- Add a svn:ignore for the new jaxws-integration module
- Cleanup imports in JaxbSchemaGenerator

Many thanks for finding the typos and the imports to Tom Seelbach!!


Modified:
    webservices/axis2/trunk/java/modules/adb-codegen/src/org/apache/axis2/schema/SchemaCompiler.java
    webservices/axis2/trunk/java/modules/adb/src/org/apache/axis2/databinding/types/soapencoding/Array.java
    webservices/axis2/trunk/java/modules/codegen/src/org/apache/axis2/wsdl/codegen/schema/AxisServiceTopElementSchemaGenerator.java
    webservices/axis2/trunk/java/modules/codegen/src/org/apache/axis2/wsdl/codegen/schema/XmlImport.java
    webservices/axis2/trunk/java/modules/codegen/src/org/apache/axis2/wsdl/codegen/schema/XmlSchema.java
    webservices/axis2/trunk/java/modules/codegen/src/org/apache/axis2/wsdl/codegen/writer/WSDL11Writer.java
    webservices/axis2/trunk/java/modules/codegen/test/org/apache/axis2/wsdl/codegen/schema/AxisServiceTopElementSchemaGeneratorTest.java
    webservices/axis2/trunk/java/modules/java2wsdl/src/org/apache/ws/java2wsdl/Java2WSDLBuilder.java
    webservices/axis2/trunk/java/modules/java2wsdl/src/org/apache/ws/java2wsdl/Java2WSDLCodegenEngine.java
    webservices/axis2/trunk/java/modules/jaxbri/src/org/apache/axis2/jaxbri/JaxbSchemaGenerator.java
    webservices/axis2/trunk/java/modules/jaxws-integration/   (props changed)
    webservices/axis2/trunk/java/modules/jaxws/src/org/apache/axis2/jaxws/wsdl/impl/SchemaReaderImpl.java
    webservices/axis2/trunk/java/modules/kernel/src/org/apache/axis2/deployment/util/Utils.java
    webservices/axis2/trunk/java/modules/kernel/src/org/apache/axis2/description/AxisService.java
    webservices/axis2/trunk/java/modules/kernel/src/org/apache/axis2/description/WSDL11ToAxisServiceBuilder.java
    webservices/axis2/trunk/java/modules/kernel/src/org/apache/axis2/description/java2wsdl/DefaultSchemaGenerator.java
    webservices/axis2/trunk/java/modules/kernel/src/org/apache/axis2/description/java2wsdl/SchemaGenerator.java
    webservices/axis2/trunk/java/modules/rmi/src/org/apache/axis2/rmi/databind/OMElementCreator.java
    webservices/axis2/trunk/java/modules/rmi/src/org/apache/axis2/rmi/wsdl/WSDL11DefinitionBuilder.java

Modified: webservices/axis2/trunk/java/modules/adb-codegen/src/org/apache/axis2/schema/SchemaCompiler.java
URL: http://svn.apache.org/viewvc/webservices/axis2/trunk/java/modules/adb-codegen/src/org/apache/axis2/schema/SchemaCompiler.java?rev=633302&r1=633301&r2=633302&view=diff
==============================================================================
--- webservices/axis2/trunk/java/modules/adb-codegen/src/org/apache/axis2/schema/SchemaCompiler.java (original)
+++ webservices/axis2/trunk/java/modules/adb-codegen/src/org/apache/axis2/schema/SchemaCompiler.java Mon Mar  3 14:19:27 2008
@@ -1716,7 +1716,7 @@
 
         } else {
             // this attribute refers to a custom type, probably one of the extended simple types.
-            // with the inline scheam definition
+            // with the inline schema definition
             QName attributeQName = att.getQName();
             if (attributeQName != null) {
                 XmlSchemaSimpleType attributeSimpleType = att.getSchemaType();
@@ -2578,7 +2578,7 @@
                                       QName componentQName,
                                       int componetType) throws SchemaCompilationException {
         // if the componet do not have a propernamesapce or
-        // it is equals to the xsd scheam namesapce
+        // it is equals to the xsd schema namesapce
         // we do not have to do any thing.
         if ((componentQName == null) ||
               (componentQName.getNamespaceURI() == null) ||

Modified: webservices/axis2/trunk/java/modules/adb/src/org/apache/axis2/databinding/types/soapencoding/Array.java
URL: http://svn.apache.org/viewvc/webservices/axis2/trunk/java/modules/adb/src/org/apache/axis2/databinding/types/soapencoding/Array.java?rev=633302&r1=633301&r2=633302&view=diff
==============================================================================
--- webservices/axis2/trunk/java/modules/adb/src/org/apache/axis2/databinding/types/soapencoding/Array.java (original)
+++ webservices/axis2/trunk/java/modules/adb/src/org/apache/axis2/databinding/types/soapencoding/Array.java Mon Mar  3 14:19:27 2008
@@ -305,7 +305,7 @@
         // since soap encoding does not enforce the name of the children items
         // here we use item as the child name.
 
-        // all the list objects must be ADBBeans for basic scheam types such as
+        // all the list objects must be ADBBeans for basic schema types such as
         // int,float corresponding soapencoding class must be used
         ADBBean adbBean;
         for (Iterator iter = objectList.iterator(); iter.hasNext();) {

Modified: webservices/axis2/trunk/java/modules/codegen/src/org/apache/axis2/wsdl/codegen/schema/AxisServiceTopElementSchemaGenerator.java
URL: http://svn.apache.org/viewvc/webservices/axis2/trunk/java/modules/codegen/src/org/apache/axis2/wsdl/codegen/schema/AxisServiceTopElementSchemaGenerator.java?rev=633302&r1=633301&r2=633302&view=diff
==============================================================================
--- webservices/axis2/trunk/java/modules/codegen/src/org/apache/axis2/wsdl/codegen/schema/AxisServiceTopElementSchemaGenerator.java (original)
+++ webservices/axis2/trunk/java/modules/codegen/src/org/apache/axis2/wsdl/codegen/schema/AxisServiceTopElementSchemaGenerator.java Mon Mar  3 14:19:27 2008
@@ -81,7 +81,7 @@
         NamespacePrefix namespacePrefix = new NamespacePrefix();
         for (Iterator iter = topElements.iterator(); iter.hasNext();) {
             topElement = (TopElement) iter.next();
-            xmlSchema = getXmlScheamForNamespace(topElement.getElementQName().getNamespaceURI(), schemaMap);
+            xmlSchema = getXmlSchemaForNamespace(topElement.getElementQName().getNamespaceURI(), schemaMap);
             if (!xmlSchema.isElementExists(topElement.getElementQName().getLocalPart())) {
                 if (topElement.getTypeQName() == null) {
                     //i.e this element is an annonymous complex element
@@ -94,7 +94,7 @@
                     // then we have an element with a complex type.
                     // first creates the complex type if it is note exists
                     XmlSchema complexElementSchema =
-                            getXmlScheamForNamespace(topElement.getTypeQName().getNamespaceURI(), schemaMap);
+                            getXmlSchemaForNamespace(topElement.getTypeQName().getNamespaceURI(), schemaMap);
                     if (!complexElementSchema.isComplexTypeExists(topElement.getTypeQName().getLocalPart())) {
                         XmlComplexType xmlComplexType = new XmlComplexType();
                         xmlComplexType.setName(topElement.getTypeQName().getLocalPart());
@@ -129,12 +129,12 @@
         return xmlElement;
     }
 
-    private XmlSchema getXmlScheamForNamespace(String targetNamespace, Map scheamMap) {
-        if (!scheamMap.containsKey(targetNamespace)) {
+    private XmlSchema getXmlSchemaForNamespace(String targetNamespace, Map schemaMap) {
+        if (!schemaMap.containsKey(targetNamespace)) {
             XmlSchema xmlSchema = new XmlSchema(targetNamespace);
-            scheamMap.put(targetNamespace, xmlSchema);
+            schemaMap.put(targetNamespace, xmlSchema);
         }
-        return (XmlSchema) scheamMap.get(targetNamespace);
+        return (XmlSchema) schemaMap.get(targetNamespace);
     }
 
     public Set getTopElements() {

Modified: webservices/axis2/trunk/java/modules/codegen/src/org/apache/axis2/wsdl/codegen/schema/XmlImport.java
URL: http://svn.apache.org/viewvc/webservices/axis2/trunk/java/modules/codegen/src/org/apache/axis2/wsdl/codegen/schema/XmlImport.java?rev=633302&r1=633301&r2=633302&view=diff
==============================================================================
--- webservices/axis2/trunk/java/modules/codegen/src/org/apache/axis2/wsdl/codegen/schema/XmlImport.java (original)
+++ webservices/axis2/trunk/java/modules/codegen/src/org/apache/axis2/wsdl/codegen/schema/XmlImport.java Mon Mar  3 14:19:27 2008
@@ -20,7 +20,7 @@
 import org.apache.axis2.namespace.Constants;
 
 /**
- * this class represents an xml scheam import
+ * this class represents an xml schema import
  */
 public class XmlImport {
 

Modified: webservices/axis2/trunk/java/modules/codegen/src/org/apache/axis2/wsdl/codegen/schema/XmlSchema.java
URL: http://svn.apache.org/viewvc/webservices/axis2/trunk/java/modules/codegen/src/org/apache/axis2/wsdl/codegen/schema/XmlSchema.java?rev=633302&r1=633301&r2=633302&view=diff
==============================================================================
--- webservices/axis2/trunk/java/modules/codegen/src/org/apache/axis2/wsdl/codegen/schema/XmlSchema.java (original)
+++ webservices/axis2/trunk/java/modules/codegen/src/org/apache/axis2/wsdl/codegen/schema/XmlSchema.java Mon Mar  3 14:19:27 2008
@@ -23,8 +23,8 @@
 import java.util.*;
 
 /**
- * this class represents and scheam object.
- * it is assumed that we consider the xsd scheama
+ * this class represents and schema object.
+ * it is assumed that we consider the xsd schemaa
  * as the defualt name space.
  *
  */

Modified: webservices/axis2/trunk/java/modules/codegen/src/org/apache/axis2/wsdl/codegen/writer/WSDL11Writer.java
URL: http://svn.apache.org/viewvc/webservices/axis2/trunk/java/modules/codegen/src/org/apache/axis2/wsdl/codegen/writer/WSDL11Writer.java?rev=633302&r1=633301&r2=633302&view=diff
==============================================================================
--- webservices/axis2/trunk/java/modules/codegen/src/org/apache/axis2/wsdl/codegen/writer/WSDL11Writer.java (original)
+++ webservices/axis2/trunk/java/modules/codegen/src/org/apache/axis2/wsdl/codegen/writer/WSDL11Writer.java Mon Mar  3 14:19:27 2008
@@ -213,18 +213,18 @@
         }
     }
 
-    private void changeLocations(Element element, Map changedScheamLocations) {
+    private void changeLocations(Element element, Map changedSchemaLocations) {
         NodeList nodeList = element.getChildNodes();
         String tagName;
         for (int i = 0; i < nodeList.getLength(); i++) {
             tagName = nodeList.item(i).getLocalName();
             if (IMPORT_TAG.equals(tagName) || INCLUDE_TAG.equals(tagName)) {
-                processImport(nodeList.item(i), changedScheamLocations);
+                processImport(nodeList.item(i), changedSchemaLocations);
             }
         }
     }
 
-    private void processImport(Node importNode, Map changedScheamLocations) {
+    private void processImport(Node importNode, Map changedSchemaLocations) {
         NamedNodeMap nodeMap = importNode.getAttributes();
         Node attribute;
         String attributeValue;
@@ -232,9 +232,9 @@
             attribute = nodeMap.item(i);
             if (attribute.getNodeName().equals("schemaLocation")) {
                 attributeValue = attribute.getNodeValue();
-                if (changedScheamLocations.get(attributeValue) != null) {
+                if (changedSchemaLocations.get(attributeValue) != null) {
                     attribute.setNodeValue(
-                            (String)changedScheamLocations.get(attributeValue));
+                            (String)changedSchemaLocations.get(attributeValue));
                 }
             }
         }

Modified: webservices/axis2/trunk/java/modules/codegen/test/org/apache/axis2/wsdl/codegen/schema/AxisServiceTopElementSchemaGeneratorTest.java
URL: http://svn.apache.org/viewvc/webservices/axis2/trunk/java/modules/codegen/test/org/apache/axis2/wsdl/codegen/schema/AxisServiceTopElementSchemaGeneratorTest.java?rev=633302&r1=633301&r2=633302&view=diff
==============================================================================
--- webservices/axis2/trunk/java/modules/codegen/test/org/apache/axis2/wsdl/codegen/schema/AxisServiceTopElementSchemaGeneratorTest.java (original)
+++ webservices/axis2/trunk/java/modules/codegen/test/org/apache/axis2/wsdl/codegen/schema/AxisServiceTopElementSchemaGeneratorTest.java Mon Mar  3 14:19:27 2008
@@ -25,9 +25,9 @@
 
 public class AxisServiceTopElementSchemaGeneratorTest extends TestCase {
 
-    public void testScheamGeneration(){
+    public void testSchemaGeneration(){
 
-        AxisServiceTopElementSchemaGenerator scheamGenerator = new AxisServiceTopElementSchemaGenerator(null);
+        AxisServiceTopElementSchemaGenerator schemaGenerator = new AxisServiceTopElementSchemaGenerator(null);
 
         Set topElements = new HashSet();
 
@@ -54,9 +54,9 @@
         topElements.add(topElement);
 
 
-        Map schemaMap = scheamGenerator.getSchemaMap(topElements);
+        Map schemaMap = schemaGenerator.getSchemaMap(topElements);
         try {
-            List xmlSchemaList = scheamGenerator.getXmlSchemaList(schemaMap);
+            List xmlSchemaList = schemaGenerator.getXmlSchemaList(schemaMap);
             org.apache.ws.commons.schema.XmlSchema xmlSchema;
             for (Iterator iter = xmlSchemaList.iterator();iter.hasNext();){
                 xmlSchema = (org.apache.ws.commons.schema.XmlSchema) iter.next();

Modified: webservices/axis2/trunk/java/modules/java2wsdl/src/org/apache/ws/java2wsdl/Java2WSDLBuilder.java
URL: http://svn.apache.org/viewvc/webservices/axis2/trunk/java/modules/java2wsdl/src/org/apache/ws/java2wsdl/Java2WSDLBuilder.java?rev=633302&r1=633301&r2=633302&view=diff
==============================================================================
--- webservices/axis2/trunk/java/modules/java2wsdl/src/org/apache/ws/java2wsdl/Java2WSDLBuilder.java (original)
+++ webservices/axis2/trunk/java/modules/java2wsdl/src/org/apache/ws/java2wsdl/Java2WSDLBuilder.java Mon Mar  3 14:19:27 2008
@@ -74,7 +74,7 @@
     private String schemaGenClassName = null;
     private boolean generateDocLitBare = false;
     private AxisConfiguration axisConfig;
-    private String customScheamLocation;
+    private String customSchemaLocation;
     // location of the class name to package mapping file
     // File is simple file with qualifiedClassName:SchemaQName
     private String mappingFileLocation;
@@ -213,7 +213,7 @@
         schemaGenerator.setNsGen(resolveNSGen());
         schemaGenerator.setPkg2nsmap(getPkg2nsMap());
         schemaGenerator.setMappingFileLocation(mappingFileLocation);
-        schemaGenerator.setCustomScheamLocation(customScheamLocation);
+        schemaGenerator.setCustomSchemaLocation(customSchemaLocation);
         if (getPkg2nsMap() != null && !getPkg2nsMap().isEmpty() &&
             (getPkg2nsMap().containsKey(ALL) || getPkg2nsMap().containsKey(ALL.toUpperCase()))) {
             schemaGenerator.setUseWSDLTypesNamespace(true);
@@ -391,12 +391,12 @@
     }
 
 
-    public String getCustomScheamLocation() {
-        return customScheamLocation;
+    public String getCustomSchemaLocation() {
+        return customSchemaLocation;
     }
 
-    public void setCustomScheamLocation(String customScheamLocation) {
-        this.customScheamLocation = customScheamLocation;
+    public void setCustomSchemaLocation(String customSchemaLocation) {
+        this.customSchemaLocation = customSchemaLocation;
     }
 
     public String getMappingFileLocation() {

Modified: webservices/axis2/trunk/java/modules/java2wsdl/src/org/apache/ws/java2wsdl/Java2WSDLCodegenEngine.java
URL: http://svn.apache.org/viewvc/webservices/axis2/trunk/java/modules/java2wsdl/src/org/apache/ws/java2wsdl/Java2WSDLCodegenEngine.java?rev=633302&r1=633301&r2=633302&view=diff
==============================================================================
--- webservices/axis2/trunk/java/modules/java2wsdl/src/org/apache/ws/java2wsdl/Java2WSDLCodegenEngine.java (original)
+++ webservices/axis2/trunk/java/modules/java2wsdl/src/org/apache/ws/java2wsdl/Java2WSDLCodegenEngine.java Mon Mar  3 14:19:27 2008
@@ -228,7 +228,7 @@
                            Java2WSDLConstants.CUSTOM_SCHEMA_LOCATION_LONG,
                            optionsMap);
         if (option != null) {
-            java2WsdlBuilder.setCustomScheamLocation(option.getOptionValue());
+            java2WsdlBuilder.setCustomSchemaLocation(option.getOptionValue());
         }
         option = loadOption(Java2WSDLConstants.SCHEMA_MAPPING_FILE_LOCATION,
                            Java2WSDLConstants.SCHEMA_MAPPING_FILE_LOCATION_LONG,

Modified: webservices/axis2/trunk/java/modules/jaxbri/src/org/apache/axis2/jaxbri/JaxbSchemaGenerator.java
URL: http://svn.apache.org/viewvc/webservices/axis2/trunk/java/modules/jaxbri/src/org/apache/axis2/jaxbri/JaxbSchemaGenerator.java?rev=633302&r1=633301&r2=633302&view=diff
==============================================================================
--- webservices/axis2/trunk/java/modules/jaxbri/src/org/apache/axis2/jaxbri/JaxbSchemaGenerator.java (original)
+++ webservices/axis2/trunk/java/modules/jaxbri/src/org/apache/axis2/jaxbri/JaxbSchemaGenerator.java Mon Mar  3 14:19:27 2008
@@ -18,16 +18,15 @@
  */
 package org.apache.axis2.jaxbri;
 
+import com.sun.xml.bind.v2.runtime.JAXBContextImpl;
+import com.sun.xml.bind.v2.runtime.JaxBeanInfo;
 import org.apache.axis2.description.java2wsdl.DefaultSchemaGenerator;
-import org.apache.axis2.description.AxisOperation;
 import org.apache.axis2.util.Loader;
 import org.apache.ws.commons.schema.XmlSchema;
 import org.w3c.dom.Document;
 import org.w3c.dom.Element;
 import org.w3c.dom.Node;
 import org.w3c.dom.NodeList;
-import org.codehaus.jam.JMethod;
-import org.codehaus.jam.JClass;
 
 import javax.xml.bind.JAXBContext;
 import javax.xml.bind.JAXBException;
@@ -45,9 +44,6 @@
 import java.util.List;
 import java.util.Map;
 import java.util.Set;
-
-import com.sun.xml.bind.v2.runtime.JaxBeanInfo;
-import com.sun.xml.bind.v2.runtime.JAXBContextImpl;
 
 public class JaxbSchemaGenerator extends DefaultSchemaGenerator {
     public JaxbSchemaGenerator(ClassLoader loader, String className,

Propchange: webservices/axis2/trunk/java/modules/jaxws-integration/
------------------------------------------------------------------------------
--- svn:ignore (added)
+++ svn:ignore Mon Mar  3 14:19:27 2008
@@ -0,0 +1,5 @@
+*.iml
+*.ipr
+*.log
+target
+build

Modified: webservices/axis2/trunk/java/modules/jaxws/src/org/apache/axis2/jaxws/wsdl/impl/SchemaReaderImpl.java
URL: http://svn.apache.org/viewvc/webservices/axis2/trunk/java/modules/jaxws/src/org/apache/axis2/jaxws/wsdl/impl/SchemaReaderImpl.java?rev=633302&r1=633301&r2=633302&view=diff
==============================================================================
--- webservices/axis2/trunk/java/modules/jaxws/src/org/apache/axis2/jaxws/wsdl/impl/SchemaReaderImpl.java (original)
+++ webservices/axis2/trunk/java/modules/jaxws/src/org/apache/axis2/jaxws/wsdl/impl/SchemaReaderImpl.java Mon Mar  3 14:19:27 2008
@@ -76,7 +76,7 @@
         Types types = wsdlDefinition.getTypes();
         if (types == null) {
             if (log.isDebugEnabled()) {
-                log.debug("WARNING: Could not find any Scheam/Types from WSDL");
+                log.debug("WARNING: Could not find any Schema/Types from WSDL");
                 log.debug("no packages will derived from WSDL schema");
             }
             return packageList;

Modified: webservices/axis2/trunk/java/modules/kernel/src/org/apache/axis2/deployment/util/Utils.java
URL: http://svn.apache.org/viewvc/webservices/axis2/trunk/java/modules/kernel/src/org/apache/axis2/deployment/util/Utils.java?rev=633302&r1=633301&r2=633302&view=diff
==============================================================================
--- webservices/axis2/trunk/java/modules/kernel/src/org/apache/axis2/deployment/util/Utils.java (original)
+++ webservices/axis2/trunk/java/modules/kernel/src/org/apache/axis2/deployment/util/Utils.java Mon Mar  3 14:19:27 2008
@@ -667,7 +667,7 @@
     }
 
     /**
-     * To add the exclude method when generating scheams , here the exclude methods
+     * To add the exclude method when generating schemas , here the exclude methods
      * will be session releated axis2 methods
      */
     public static void addExcludeMethods(ArrayList excludeList) {

Modified: webservices/axis2/trunk/java/modules/kernel/src/org/apache/axis2/description/AxisService.java
URL: http://svn.apache.org/viewvc/webservices/axis2/trunk/java/modules/kernel/src/org/apache/axis2/description/AxisService.java?rev=633302&r1=633301&r2=633302&view=diff
==============================================================================
--- webservices/axis2/trunk/java/modules/kernel/src/org/apache/axis2/description/AxisService.java (original)
+++ webservices/axis2/trunk/java/modules/kernel/src/org/apache/axis2/description/AxisService.java Mon Mar  3 14:19:27 2008
@@ -177,7 +177,7 @@
     private String name;
     private ClassLoader serviceClassLoader;
 
-    //to keep the XMLScheam getting either from WSDL or java2wsdl
+    //to keep the XMLSchema getting either from WSDL or java2wsdl
     private ArrayList schemaList;
     //private XmlSchema schema;
 
@@ -2208,7 +2208,7 @@
                     XmlSchemaExternal externalSchema = (XmlSchemaExternal) item;
                     s = externalSchema.getSchema();
 
-                    if (s != null && getScheamLocationWithDot(sourceURIToNewLocationMap, s) == null) {
+                    if (s != null && getSchemaLocationWithDot(sourceURIToNewLocationMap, s) == null) {
                         //insert the name into the table
                         insertIntoNameTable(nameTable, s, sourceURIToNewLocationMap, overrideAbsoluteAddress);
                         //recursively call the same procedure
@@ -2293,7 +2293,7 @@
      */
     private void adjustSchemaName(XmlSchema parentSchema,
                                   Hashtable nameTable,
-                                  Hashtable importedScheams,
+                                  Hashtable importedSchemas,
                                   Hashtable sourceURIToNewLocationMap) {
         XmlSchemaObjectCollection includes = parentSchema.getIncludes();
         for (int j = 0; j < includes.getCount(); j++) {
@@ -2304,7 +2304,7 @@
                 adjustSchemaLocation(s,
                         xmlSchemaExternal,
                         nameTable,
-                        importedScheams,
+                        importedSchemas,
                         sourceURIToNewLocationMap);
             }
         }
@@ -2321,24 +2321,24 @@
     private void adjustSchemaLocation(XmlSchema s,
                                       XmlSchemaExternal xmlSchemaExternal,
                                       Hashtable nameTable,
-                                      Hashtable importedScheams,
+                                      Hashtable importedSchemas,
                                       Hashtable sourceURIToNewLocationMap) {
         if (s != null) {
             String schemaLocation = xmlSchemaExternal.getSchemaLocation();
             
             if (schemaLocation.indexOf("://") == -1) {
-                String newscheamlocation = customSchemaNamePrefix == null ?
+                String newschemalocation = customSchemaNamePrefix == null ?
                         //use the default mode
-                        (getName() + "?xsd=" + getScheamLocationWithDot(sourceURIToNewLocationMap, s)) :
+                        (getName() + "?xsd=" + getSchemaLocationWithDot(sourceURIToNewLocationMap, s)) :
                             //custom prefix is present - add the custom prefix
-                            (customSchemaNamePrefix + getScheamLocationWithDot(sourceURIToNewLocationMap, s));
-                xmlSchemaExternal.setSchemaLocation(newscheamlocation);
-                importedScheams.put(schemaLocation, newscheamlocation);
+                            (customSchemaNamePrefix + getSchemaLocationWithDot(sourceURIToNewLocationMap, s));
+                xmlSchemaExternal.setSchemaLocation(newschemalocation);
+                importedSchemas.put(schemaLocation, newschemalocation);
             }
         }
     }
 
-    private Object getScheamLocationWithDot(Hashtable sourceURIToNewLocationMap, XmlSchema s) {
+    private Object getSchemaLocationWithDot(Hashtable sourceURIToNewLocationMap, XmlSchema s) {
         String o = (String) sourceURIToNewLocationMap.get(s.getSourceURI());
         if (o !=null && o.indexOf(".") <0){
             return o + ".xsd";

Modified: webservices/axis2/trunk/java/modules/kernel/src/org/apache/axis2/description/WSDL11ToAxisServiceBuilder.java
URL: http://svn.apache.org/viewvc/webservices/axis2/trunk/java/modules/kernel/src/org/apache/axis2/description/WSDL11ToAxisServiceBuilder.java?rev=633302&r1=633301&r2=633302&view=diff
==============================================================================
--- webservices/axis2/trunk/java/modules/kernel/src/org/apache/axis2/description/WSDL11ToAxisServiceBuilder.java (original)
+++ webservices/axis2/trunk/java/modules/kernel/src/org/apache/axis2/description/WSDL11ToAxisServiceBuilder.java Mon Mar  3 14:19:27 2008
@@ -1608,7 +1608,7 @@
                                                  namespaceImportsMap,
                                                  namespaceToUse);
                 } else if (newSchemaMap.containsKey(namespaceToUse)) {
-                    // i.e this namespace is with a newly created scheam
+                    // i.e this namespace is with a newly created schema
                     addElementToAnExistingSchema((Element) newSchemaMap.get(namespaceToUse),
                                                  elementDeclaration,
                                                  namespacePrefixMap,
@@ -1702,7 +1702,7 @@
                                                  namespaceImportsMap,
                                                  namespaceToUse);
                 } else if (newSchemaMap.containsKey(namespaceToUse)) {
-                    // i.e this namespace is with a newly created scheam
+                    // i.e this namespace is with a newly created schema
                     addElementToAnExistingSchema((Element) newSchemaMap.get(namespaceToUse),
                                                  elementDeclaration,
                                                  namespacePrefixMap,

Modified: webservices/axis2/trunk/java/modules/kernel/src/org/apache/axis2/description/java2wsdl/DefaultSchemaGenerator.java
URL: http://svn.apache.org/viewvc/webservices/axis2/trunk/java/modules/kernel/src/org/apache/axis2/description/java2wsdl/DefaultSchemaGenerator.java?rev=633302&r1=633301&r2=633302&view=diff
==============================================================================
--- webservices/axis2/trunk/java/modules/kernel/src/org/apache/axis2/description/java2wsdl/SchemaGenerator.java (original)
+++ webservices/axis2/trunk/java/modules/kernel/src/org/apache/axis2/description/java2wsdl/SchemaGenerator.java Mon Mar  3 14:19:27 2008
@@ -55,10 +55,10 @@
 
     void setAxisService(AxisService service);
 
-    String getCustomScheamLocation();
+    String getCustomSchemaLocation();
 
 
-    void setCustomScheamLocation(String customScheamLocation);
+    void setCustomSchemaLocation(String customSchemaLocation);
 
     String getMappingFileLocation() ;
 

Modified: webservices/axis2/trunk/java/modules/rmi/src/org/apache/axis2/rmi/databind/OMElementCreator.java
URL: http://svn.apache.org/viewvc/webservices/axis2/trunk/java/modules/rmi/src/org/apache/axis2/rmi/databind/OMElementCreator.java?rev=633302&r1=633301&r2=633302&view=diff
==============================================================================
--- webservices/axis2/trunk/java/modules/rmi/src/org/apache/axis2/rmi/databind/OMElementCreator.java (original)
+++ webservices/axis2/trunk/java/modules/rmi/src/org/apache/axis2/rmi/databind/OMElementCreator.java Mon Mar  3 14:19:27 2008
@@ -71,7 +71,7 @@
         } catch (MetaDataPopulateException e) {
             throw new OMElementCreationException("Problem in meta data population", e);
         } catch (SchemaGenerationException e) {
-            throw new OMElementCreationException("Problem in Scheam generation", e);
+            throw new OMElementCreationException("Problem in Schema generation", e);
         }
 
         return returnOMElement;

Modified: webservices/axis2/trunk/java/modules/rmi/src/org/apache/axis2/rmi/wsdl/WSDL11DefinitionBuilder.java
URL: http://svn.apache.org/viewvc/webservices/axis2/trunk/java/modules/rmi/src/org/apache/axis2/rmi/wsdl/WSDL11DefinitionBuilder.java?rev=633302&r1=633301&r2=633302&view=diff
==============================================================================
--- webservices/axis2/trunk/java/modules/rmi/src/org/apache/axis2/rmi/wsdl/WSDL11DefinitionBuilder.java (original)
+++ webservices/axis2/trunk/java/modules/rmi/src/org/apache/axis2/rmi/wsdl/WSDL11DefinitionBuilder.java Mon Mar  3 14:19:27 2008
@@ -87,7 +87,7 @@
     }
 
     /**
-     * generates the scheams for the wsdl
+     * generates the schemas for the wsdl
      *
      * @throws SchemaGenerationException
      */



---------------------------------------------------------------------
To unsubscribe, e-mail: axis-cvs-unsubscribe@ws.apache.org
For additional commands, e-mail: axis-cvs-help@ws.apache.org
--- webservices/axis2/trunk/java/modules/kernel/src/org/apache/axis2/description/java2wsdl/DefaultSchemaGenerator.java (original)
+++ webservices/axis2/trunk/java/modules/kernel/src/org/apache/axis2/description/java2wsdl/DefaultSchemaGenerator.java Mon Mar  3 14:19:27 2008
@@ -94,7 +94,7 @@
     protected Class serviceClass = null;
     protected AxisService service;
     // location of the custom schema , if any
-    protected String customScheamLocation;
+    protected String customSchemaLocation;
     // location of the class name to package mapping file
     // File is simple file with qualifiedClassName:SchemaQName
     protected String mappingFileLocation;
@@ -145,13 +145,13 @@
         }
     }
 
     //This will locad the custom scheam file and add that into the scheam map
     private void loadCustomSchemaFile(){
-      if (customScheamLocation != null) {
+      if (customSchemaLocation != null) {
           try {
               DocumentBuilderFactory documentBuilderFactory = DocumentBuilderFactory.newInstance();
               documentBuilderFactory.setNamespaceAware(true);
-              Document doc = documentBuilderFactory.newDocumentBuilder().parse(new File(customScheamLocation));
+              Document doc = documentBuilderFactory.newDocumentBuilder().parse(new File(customSchemaLocation));
               XmlSchema schema = xmlSchemaCollection.read(doc,null);
               schemaMap.put(schema.getTargetNamespace() ,schema);
           } catch (Exception e) {
@@ -1077,12 +1077,12 @@
     }
 
 
-    public String getCustomScheamLocation() {
-        return customScheamLocation;
+    public String getCustomSchemaLocation() {
+        return customSchemaLocation;
     }
 
-    public void setCustomScheamLocation(String customScheamLocation) {
-        this.customScheamLocation = customScheamLocation;
+    public void setCustomSchemaLocation(String customSchemaLocation) {
+        this.customSchemaLocation = customSchemaLocation;
     }
 
     public String getMappingFileLocation() {
@@ -145,13 +145,13 @@
     }
 
-    //This will locad the custom scheam file and add that into the scheam map
+    //This will locad the custom schema file and add that into the schema map
     private void loadCustomSchemaFile(){

Modified: webservices/axis2/trunk/java/modules/kernel/src/org/apache/axis2/description/java2wsdl/SchemaGenerator.java
URL: http://svn.apache.org/viewvc/webservices/axis2/trunk/java/modules/kernel/src/org/apache/axis2/description/java2wsdl/SchemaGenerator.java?rev=633302&r1=633301&r2=633302&view=diff
==============================================================================